package cn.estsh.i3plus.ext.mes.pcn.apiservice.controller.busi;


import cn.estsh.i3plus.ext.mes.pcn.api.busi.IMesNcProcessingService;
import cn.estsh.i3plus.ext.mes.pcn.pojo.constant.MesCommonConstant;
import cn.estsh.i3plus.ext.mes.pcn.pojo.util.MesPcnExtEnumUtil;
import cn.estsh.impp.framework.boot.auth.AuthUtil;
import cn.estsh.impp.framework.boot.exception.ImppBusiException;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ResultBean;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

@RestController
@Api(tags = "NC处理页面")
@RequestMapping(MesCommonConstant.MES_YANFEN + "/nc-processing")
@Slf4j
public class MesNcProcessingController {

    @Autowired
    private IMesNcProcessingService ncProcessingService;


    @GetMapping("/query")
    @ApiOperation(value = "查询产品条码")
    public ResultBean queryProduceSn(String serialNumber) {

        try {
            // 数据校验
            ValidatorBean.checkNotNull(serialNumber, "产品条码不能为空");

            return ResultBean.success("查询成功").setResultObject(ncProcessingService.queryProduceSn(serialNumber, AuthUtil.getOrganizeCode()));
        } catch (ImppBusiException imppException) {
            return ResultBean.fail(imppException);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @PostMapping("/save-nc")
    @ApiOperation(value = "NC处理")
    public ResultBean saveNc(@RequestBody String serialNumber, String person, Integer type) {

        try {
            // 数据校验
            ValidatorBean.checkNotNull(serialNumber, "产品条码不能为空");

            String description = MesPcnExtEnumUtil.NC_TYPE.valueOfDescription(type);
            if (StringUtils.isEmpty(description)) {
                throw new ImppBusiException(String.format("【%s】类型不存在，请检查数据", type));

            }

            ncProcessingService.saveNc(serialNumber, person, type, AuthUtil.getOrganizeCode());
            return ResultBean.success("查询成功");
        } catch (ImppBusiException imppException) {
            return ResultBean.fail(imppException);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

}
